@@ -41,7 +41,7 @@
 // ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 // POSSIBILITY OF SUCH DAMAGE.
 
-#include "recon.h"
+#include "libtomo/recon.h"
 #include "utils.h"
 
 void
