@@ -49,9 +49,6 @@
 Module for pre-processing tasks.
 """
 
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
-
 import numpy as np
 import pywt
 import tomopy.util.extern as extern
@@ -283,8 +280,7 @@ def _ring(sino, m, n):
     N = np.size(mysino, 1)
 
     # Remove NaN.
-    pos = np.where(np.isnan(mysino) is True)
-    mysino[pos] = 0
+    mysino[np.isnan(mysino)] = 0
 
     # Parameter.
     alpha = _get_parameter(mysino)
@@ -480,7 +476,7 @@ def remove_stripe_based_filtering(tomo,
 
 
 def _create_1d_window(ncol, sigma, pad):
-    window = signal.gaussian(ncol + 2 * pad, std=sigma)
+    window = signal.windows.gaussian(ncol + 2 * pad, std=sigma)
     return window
 
 
@@ -823,10 +819,14 @@ def _rs_dead(sinogram, snr, size, matindex, norm=True):
     listx = np.where(listmask < 1.0)[0]
     listy = np.arange(nrow)
     matz = sinogram[:, listx]
-    finter = interpolate.interp2d(listx, listy, matz, kind='linear')
+    finter = interpolate.RectBivariateSpline(listy, listx, matz,
+                                             kx=1, ky=1)
     listxmiss = np.where(listmask > 0.0)[0]
     if len(listxmiss) > 0:
-        sinogram[:, listxmiss] = finter(listxmiss, listy)
+        matxmiss, maty = np.meshgrid(listxmiss, listy)
+        output = finter.ev(np.ndarray.flatten(maty),
+                           np.ndarray.flatten(matxmiss))
+        sinogram[:, listxmiss] = output.reshape(matxmiss.shape)
     # Remove residual stripes
     if norm is True:
         sinogram = _rs_large(sinogram, snr, size, matindex)
@@ -963,10 +963,14 @@ def _rs_interpolation(sinogram, snr, size, drop_ratio=0.1, norm=True):
     listx = np.where(listmask < 1.0)[0]
     listy = np.arange(nrow)
     matz = sinogram[:, listx]
-    finter = interpolate.interp2d(listx, listy, matz, kind='linear')
+    finter = interpolate.RectBivariateSpline(listy, listx, matz,
+                                             kx=1, ky=1)
     listxmiss = np.where(listmask > 0.0)[0]
     if len(listxmiss) > 0:
-        sinogram[:, listxmiss] = finter(listxmiss, listy)
+        matxmiss, maty = np.meshgrid(listxmiss, listy)
+        output = finter.ev(np.ndarray.flatten(maty),
+                           np.ndarray.flatten(matxmiss))
+        sinogram[:, listxmiss] = output.reshape(matxmiss.shape)
     return sinogram
 
 
@@ -1063,7 +1067,7 @@ def stripes_mask3d(weights,
     binary 3D mask with ones where stripes present.
 
     The method tries to eliminate non-stripe features in data by checking the
-    consistency of weights in three directions. The algorithm is 
+    consistency of weights in three directions. The algorithm is
     presented in the paper :cite:`Kazantsev:23`.
 
     .. versionadded:: 1.14
