@@ -262,6 +262,10 @@ def recon(tomo,
     # Initialize tomography data.
     tomo = init_tomo(tomo, sinogram_order, sharedmem=False)
 
+    if tomo.shape[1] != len(theta):
+        msg = 'There must be one angle for every projection.'
+        raise ValueError(msg)
+
     generic_kwargs = ['num_gridx', 'num_gridy', 'options']
 
     # Generate kwargs for the algorithm.
@@ -310,6 +314,11 @@ def recon(tomo,
 
     # Generate args for the algorithm.
     center_arr = get_center(tomo.shape, center)
+
+    if tomo.shape[0] != len(center_arr):
+        msg = 'There must be one center for every slice.'
+        raise ValueError(msg)
+
     args = _get_algorithm_args(theta)
 
     # Initialize reconstruction.
@@ -439,9 +448,15 @@ def _dist_recon(tomo, center, recon, algorithm, args, kwargs, ncore, nchunk):
         else:
             # execute recon on ncore threads
             with cf.ThreadPoolExecutor(ncore) as e:
-                for slc in use_slcs:
+                futures = [
                     e.submit(algorithm, tomo[slc], center[slc], recon[slc],
-                             *args, **kwargs)
+                             *args, **kwargs) for slc in use_slcs
+                ]
+            done, _ = cf.wait(futures, return_when=cf.ALL_COMPLETED)
+            for f in done:
+                if f.exception() is not None:
+                    raise f.exception()
+
 
     if pythreads is not None:
         # reset to default
