@@ -50,9 +50,6 @@
 Module for simulation of x-rays.
 """
 
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
-
 import numpy as np
 import tomopy.util.extern as extern
 import tomopy.util.dtype as dtype
