@@ -50,9 +50,6 @@
 Module for multiprocessing tasks.
 """
 
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
-
 import numpy as np
 import multiprocessing as mp
 import math
